@@ -1,6 +1,7 @@
 import sys
 import math
 import json
+from datetime import datetime, timedelta
 try:
     from urllib.parse import urlparse, parse_qs
 except ImportError:
@@ -45,7 +46,7 @@ class SkillCornerClient(object):
                                timeout=timeout, **kwargs)
 
     def request(self, end_point, method='GET', params=None, json=None,
-                retries=2, backoff_factor=0.5, timeout=5, **kwargs):
+                retries=2, backoff_factor=0.5, timeout=5, session=None, **kwargs):
         """
         Wraps _request to call it with end_point, and eventually retry the request
 
@@ -58,6 +59,7 @@ class SkillCornerClient(object):
             params (dict, optional): any query param to pass to the request
             json (dict, optional): json payload to send
             timeout (float, optional): timeout of the request
+            session (requests.Session, optional): pass a session if you want to use persistent HTTP connection
             **kwargs: any other kwargs will be pass to the _request method (then to Session.request)
 
         Returns:
@@ -67,7 +69,8 @@ class SkillCornerClient(object):
             requests.RequestException: http://docs.python-requests.org/en/latest/user/quickstart/#errors-and-exceptions
         """
         request_url = '{}{}'.format(self.backend_url, end_point)
-        session = requests.Session()
+        if not session:
+            session = requests.Session()
         retry = Retry(total=retries, backoff_factor=backoff_factor, status_forcelist=(500, 502, 503, 504))
         session.mount('https://', HTTPAdapter(max_retries=retry))
         return self._request(session=session, method=method, url=request_url, json=json, params=params,
@@ -93,11 +96,12 @@ class SkillCornerClient(object):
         offset = params.get('offset')
         if verbose:
             page_nb = 0
+        session = requests.Session()
         while request_next:
             if limit and offset:
                 params['limit'] = limit
                 params['offset'] = offset
-            resp = self.request(end_point, params=params)
+            resp = self.request(end_point, params=params, session=session)
             if resp.status_code != 200:
                 return resp.json()
             resp = resp.json()
@@ -130,9 +134,10 @@ class SkillCornerClient(object):
             dict: json parsed response from skillcorner api
         """
         end_point = '/api/match/{}'.format(match_id)
+        params = {}
         if sr_matching:
-            end_point += '/sr_matching'
-        return self.request(end_point).json()
+            params['matching'] = 'sportradar'
+        return self.request(end_point, params=params).json()
 
     def get_video_data(self, match_id):
         """
@@ -163,7 +168,13 @@ class SkillCornerClient(object):
         match_live_endpoint = '/api/match/{}/match_live'.format(match_id)
         return self.request(match_live_endpoint).json()
 
-    def get_matches_list(self, min_date=None, max_date=None, sr_matching=False, verbose=False):
+    def get_matches_list(
+        self,
+        min_date=datetime.now() - timedelta(days=30),
+        max_date=None,
+        sr_matching=False,
+        verbose=False
+    ):
         """
         Get matches list from api which provides team names and date for each match covered by SkillCorner
 
@@ -177,9 +188,9 @@ class SkillCornerClient(object):
             dict: json parsed response from skillcorner api
         """
         end_point = '/api/matches'
-        if sr_matching:
-            end_point += '/sr_matching'
         params = {'limit': 300}
+        if sr_matching:
+            params['matching'] = 'sportradar'
         if min_date:
             params['date_time__gte'] = min_date
         if max_date:
